import { Query } from '@kevisual/query';
import type { Result, DataOpts } from '@kevisual/query/query';
import { setBaseResponse } from '@kevisual/query/query';

export type QueryMarkOpts = {
  query?: Query;
  isBrowser?: boolean;
  onLoad?: () => void;
  storage?: Storage;
  cache: Cache;
};
export type QueryMarkData = {
  id?: string;
  title?: string;
  description?: string;
  [key: string]: any;
};
export type QueryMarkResult = {
  accessToken: string;
  refreshToken: string;
};

export class QueryMark {
  query: Query;
  isBrowser: boolean;
  load?: boolean;
  storage: Storage;
  onLoad?: () => void;

  constructor(opts?: QueryMarkOpts) {
    this.query = opts?.query || new Query();
    this.isBrowser = opts?.isBrowser ?? true;
    this.init();
    this.onLoad = opts?.onLoad;
    this.storage = opts?.storage || localStorage;
  }
  setQuery(query: Query) {
    this.query = query;
  }
  private async init() {
    this.load = true;
    this.onLoad?.();
  }
  async post<T = any>(data: any, opts?: DataOpts) {
    try {
      return this.query.post<T>({ path: 'mark', ...data }, opts);
    } catch (error) {
      console.log('error', error);
      return {
        code: 400,
      } as any;
    }
  }
}
